/**************************************************************************
 *  This file is part of QuteScoop.
 *  Copyright (C) 2007-2008 Martin Domig <martin@domig.net>
 *
 *  QuteScoop is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  QuteScoop is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with QuteScoop.  If not, see <http://www.gnu.org/licenses/>
 **************************************************************************/

#ifndef AIRPORT_H_
#define AIRPORT_H_

#include <QStringList>
#include <QGLWidget>

#include "MapObject.h"
#include "Controller.h"
#include "Pilot.h"
#include "Metar.h"

class Pilot;

class Airport: public MapObject
{
public:
	Airport();
	Airport(const QStringList& list);
	~Airport();
	
	virtual QString toolTip() const;
	virtual void showDetailsDialog();
	virtual QString mapLabel() const;
	
	virtual bool matches(const QRegExp& regex) const;

	QString name;
	QString city;
	QString countryCode;
	
	void resetWhazzupStatus();
	
	bool isActive() { return active; };
	
	const QList<Controller*>& getTowers() const { return towers; };
	const QList<Controller*>& getGrounds() const { return grounds; };
	const QList<Controller*>& getApproaches() const { return approaches; };
	
	const QList<Pilot*>& getArrivals() const { return arrivals; };
	const QList<Pilot*>& getDepartures() const { return departures; };
	
	QList<Controller*> getAllControllers() const;
	
	void addArrival(Pilot* client);
	void addDeparture(Pilot* client);
	
	void addApproach(Controller* client);
	void addTower(Controller* client);
	void addGround(Controller* client);
	
	void toggleFlightLines();
	void setDisplayFlightLines(bool show);
	void refreshAfterUpdate();
	
	const GLuint& getAppDisplayList();
	const GLuint& getAppBorderDisplayList();
	const GLuint& getTwrDisplayList();
	const GLuint& getGndDisplayList();
	
	Metar metar;

private:
	void createAppDisplayLists();
	bool showFlightLines;
		
	bool active;
	QList<Controller*> towers;
	QList<Controller*> grounds;
	QList<Controller*> approaches;

	QList<Pilot*> arrivals;
	QList<Pilot*> departures;
	
	GLuint appDisplayList;
	GLuint appBorderDisplayList;
	GLuint twrDisplayList;
	GLuint gndDisplayList;
};

#endif /*AIRPORT_H_*/
